@@ -1,10 +1,14 @@
+from whisperplus.pipelines.whisper_autocaption import WhisperAutoCaptionPipeline
+
+from whisperplus.pipelines.autollm_chatbot import AutoLLMChatWithVideo
+from whisperplus.pipelines.long_text_summarization import LongTextSummarizationPipeline
 from whisperplus.pipelines.summarization import TextSummarizationPipeline
+from whisperplus.pipelines.text2speech import TextToSpeechPipeline
 from whisperplus.pipelines.whisper import SpeechToTextPipeline
 from whisperplus.pipelines.whisper_diarize import ASRDiarizationPipeline
 from whisperplus.utils.download_utils import download_and_convert_to_mp3
 from whisperplus.utils.text_utils import format_speech_to_dialogue
 
-__version__ = '0.0.6'
+__version__ = '0.3.3'
 __author__ = 'kadirnar'
 __license__ = 'Apache License 2.0'
-__all__ = ['']
